@@ -7,11 +7,15 @@
 		hourText: 'Hodiny',
 		minuteText: 'Minuty',
 		secondText: 'Vteřiny',
+		millisecText: 'Milisekundy',
 		timezoneText: 'Časové pásmo',
 		currentText: 'Nyní',
 		closeText: 'Zavřít',
 		timeFormat: 'h:m',
-		ampm: false
+		amNames: ['dop.', 'AM', 'A'],
+		pmNames: ['odp.', 'PM', 'P'],
+		ampm: false,
+		isRTL: false
 	};
 	$.timepicker.setDefaults($.timepicker.regional['cs']);
 })(jQuery);
