@@ -7,11 +7,15 @@
 		hourText: 'Pukul',
 		minuteText: 'Menit',
 		secondText: 'Detik',
+		millisecText: 'Milidetik',
 		timezoneText: 'Zona Waktu',
 		currentText: 'Sekarang',
 		closeText: 'OK',
 		timeFormat: 'hh:mm tt',
-		ampm: false
+		amNames: ['AM', 'A'],
+		pmNames: ['PM', 'P'],
+		ampm: false,
+		isRTL: false
 	};
 	$.timepicker.setDefaults($.timepicker.regional['id']);
 })(jQuery);
