@@ -7,11 +7,15 @@
         hourText: 'Ora',
         minuteText: 'Minuto',
         secondText: 'Secondo',
+        millisecText: 'Millisecondo',
         timezoneText: 'Fuso orario',
         currentText: 'Adesso',
         closeText: 'Chiudi',
         timeFormat: 'hh:mm',
-        ampm: false
+        amNames: ['m.', 'AM', 'A'],
+        pmNames: ['p.', 'PM', 'P'],
+        ampm: false,
+        isRTL: false
     };
     $.timepicker.setDefaults($.timepicker.regional['it']);
 })(jQuery);
